@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -112,7 +112,7 @@ void RichTextComposer::createActions(KActionCollection *ac)
 
 void RichTextComposer::updateHighLighter()
 {
-    KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *hlighter = dynamic_cast<KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *>(highlighter());
+    KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *hlighter = qobject_cast<KPIMTextEdit::RichTextComposerEmailQuoteHighlighter *>(highlighter());
     if (hlighter) {
         hlighter->toggleSpellHighlighting(checkSpellingEnabled());
     }
