@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -37,38 +37,38 @@ class Q_DECL_HIDDEN RichTextComposerActions::RichTextComposerActionsPrivate
 public:
     RichTextComposerActionsPrivate(KPIMTextEdit::RichTextComposerControler *controler)
         : composerControler(controler),
-          action_align_left(Q_NULLPTR),
-          action_align_right(Q_NULLPTR),
-          action_align_center(Q_NULLPTR),
-          action_align_justify(Q_NULLPTR),
-          action_direction_ltr(Q_NULLPTR),
-          action_direction_rtl(Q_NULLPTR),
-          action_text_superscript(Q_NULLPTR),
-          action_text_subscript(Q_NULLPTR),
-          action_text_bold(Q_NULLPTR),
-          action_text_italic(Q_NULLPTR),
-          action_text_underline(Q_NULLPTR),
-          action_text_strikeout(Q_NULLPTR),
-          action_font_family(Q_NULLPTR),
-          action_font_size(Q_NULLPTR),
-          action_insert_horizontal_rule(Q_NULLPTR),
-          action_text_foreground_color(Q_NULLPTR),
-          action_text_background_color(Q_NULLPTR),
-          action_manage_link(Q_NULLPTR),
-          action_list_indent(Q_NULLPTR),
-          action_list_dedent(Q_NULLPTR),
-          action_list_style(Q_NULLPTR),
-          action_paste_quotation(Q_NULLPTR),
-          action_add_quote_chars(Q_NULLPTR),
-          action_remove_quote_chars(Q_NULLPTR),
-          action_paste_without_formatting(Q_NULLPTR),
-          action_add_image(Q_NULLPTR),
-          action_add_emoticon(Q_NULLPTR),
-          action_insert_html(Q_NULLPTR),
-          action_add_table(Q_NULLPTR),
-          action_delete_line(Q_NULLPTR),
-          action_format_reset(Q_NULLPTR),
-          action_format_painter(Q_NULLPTR),
+          action_align_left(nullptr),
+          action_align_right(nullptr),
+          action_align_center(nullptr),
+          action_align_justify(nullptr),
+          action_direction_ltr(nullptr),
+          action_direction_rtl(nullptr),
+          action_text_superscript(nullptr),
+          action_text_subscript(nullptr),
+          action_text_bold(nullptr),
+          action_text_italic(nullptr),
+          action_text_underline(nullptr),
+          action_text_strikeout(nullptr),
+          action_font_family(nullptr),
+          action_font_size(nullptr),
+          action_insert_horizontal_rule(nullptr),
+          action_text_foreground_color(nullptr),
+          action_text_background_color(nullptr),
+          action_manage_link(nullptr),
+          action_list_indent(nullptr),
+          action_list_dedent(nullptr),
+          action_list_style(nullptr),
+          action_paste_quotation(nullptr),
+          action_add_quote_chars(nullptr),
+          action_remove_quote_chars(nullptr),
+          action_paste_without_formatting(nullptr),
+          action_add_image(nullptr),
+          action_add_emoticon(nullptr),
+          action_insert_html(nullptr),
+          action_add_table(nullptr),
+          action_delete_line(nullptr),
+          action_format_reset(nullptr),
+          action_format_painter(nullptr),
           richTextEnabled(false)
     {
     }
@@ -414,7 +414,9 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
 
     d->action_add_quote_chars = new QAction(i18n("Add &Quote Characters"), this);
     d->action_add_quote_chars->setObjectName(QStringLiteral("tools_quote"));
-    ac->addAction(QStringLiteral("tools_quote"), d->action_add_quote_chars);
+    if (ac) {
+        ac->addAction(QStringLiteral("tools_quote"), d->action_add_quote_chars);
+    }
     connect(d->action_add_quote_chars, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotAddQuotes);
 
     d->action_remove_quote_chars = new QAction(i18n("Re&move Quote Characters"), this);
@@ -468,7 +470,9 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     }
 
     d->action_delete_line = new QAction(i18n("Delete Line"), this);
-    ac->setDefaultShortcut(d->action_delete_line, QKeySequence(Qt::CTRL + Qt::Key_K));
+    if (ac) {
+        ac->setDefaultShortcut(d->action_delete_line, QKeySequence(Qt::CTRL + Qt::Key_K));
+    }
     d->action_delete_line->setObjectName(QStringLiteral("delete_line"));
     if (ac) {
         ac->addAction(QStringLiteral("delete_line"), d->action_delete_line);
@@ -481,7 +485,9 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     d->action_format_reset->setIconText(i18n("Reset Font"));
     d->action_format_reset->setObjectName(QStringLiteral("format_reset"));
     connect(d->action_format_reset, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotFormatReset);
-    ac->addAction(QStringLiteral("format_reset"), d->action_format_reset);
+    if (ac) {
+        ac->addAction(QStringLiteral("format_reset"), d->action_format_reset);
+    }
     d->richTextActionList.append(d->action_format_reset);
 
     d->action_format_painter = new KToggleAction(QIcon::fromTheme(QStringLiteral("draw-brush")),
