@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
   based on code from kopete
 
   This library is free software; you can redistribute it and/or modify it
@@ -67,6 +67,7 @@ class EmoticonTextEditSelector::EmoticonTextEditSelectorPrivate
 {
 public:
     EmoticonTextEditSelectorPrivate()
+        : listEmoticon(nullptr)
     {
     }
     QListWidget *listEmoticon;
@@ -111,10 +112,11 @@ void EmoticonTextEditSelector::slotCreateEmoticonList()
     exclude << QStringLiteral("(g)") << QStringLiteral("(F)") << QStringLiteral("(f)") << QStringLiteral("(H)");
     exclude << QStringLiteral("8)") << QStringLiteral("(N)") << QStringLiteral("(n)") << QStringLiteral("(Y)") << QStringLiteral("(y)") << QStringLiteral("(U)") << QStringLiteral("(u)") << QStringLiteral("(W)") << QStringLiteral("(w)");
 
-    QHash<QString, QStringList>::const_iterator end = list.constEnd();
+    const QHash<QString, QStringList>::const_iterator end = list.constEnd();
     for (QHash<QString, QStringList>::const_iterator it = list.constBegin(); it != end; ++it) {
-        if (!exclude.contains(it.value().first())) {
-            new EmoticonTextEditItem(it.value().first(), it.key(), d->listEmoticon);
+        const QString str = it.value().first();
+        if (!exclude.contains(str)) {
+            new EmoticonTextEditItem(str, it.key(), d->listEmoticon);
         }
     }
 
