@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,7 +29,7 @@ class TextToSpeechWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit TextToSpeechWidgetTest(QObject *parent = Q_NULLPTR);
+    explicit TextToSpeechWidgetTest(QObject *parent = nullptr);
 
 private:
     void addInterface(KPIMTextEdit::TextToSpeechWidget *widget);
